@@ -1,14 +1,4 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.agenda.forms
-    ~~~~~~~~~~~~~~~~~~~~~~~
-
-    Forms for the agenda app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 
 import re
 
@@ -16,28 +6,33 @@ from django import forms
 from django.utils.translation import ugettext_lazy
 from mptt.forms import TreeNodeChoiceField
 
-from openslides.utils.forms import CssClassMixin
+from openslides.utils.forms import CssClassMixin, CleanHtmlFormMixin
 from openslides.utils.person.forms import PersonFormField
+
 from .models import Item, Speaker
 
 
-class ItemForm(CssClassMixin, forms.ModelForm):
+class ItemForm(CleanHtmlFormMixin, CssClassMixin, forms.ModelForm):
     """
     Form to create of update an item.
     """
+
+    clean_html_fields = ('text', )
+
     parent = TreeNodeChoiceField(
         queryset=Item.objects.all(), label=ugettext_lazy("Parent item"), required=False)
 
     duration = forms.RegexField(
-        regex=re.compile('[0-99]:[0-5][0-9]'),
+        regex=re.compile('^(?:[0-9]{1,2}:[0-5][0-9]|[0-9]+)$'),
         error_message=ugettext_lazy("Invalid format. Hours from 0 to 99 and minutes from 00 to 59"),
         max_length=5,
         required=False,
-        label=ugettext_lazy("Duration (hh:mm)"))
+        label=ugettext_lazy("Duration"),
+        help_text=ugettext_lazy('Input format: HH:MM or M or MM or MMM'))
 
     class Meta:
         model = Item
-        exclude = ('closed', 'weight', 'related_sid')
+        exclude = ('closed', 'weight', 'content_type', 'object_id')
 
 
 class RelatedItemForm(ItemForm):
@@ -46,7 +41,7 @@ class RelatedItemForm(ItemForm):
     """
     class Meta:
         model = Item
-        exclude = ('closed', 'type', 'weight', 'related_sid', 'title', 'text')
+        exclude = ('closed', 'type', 'weight', 'content_type', 'object_id', 'title', 'text')
 
 
 class ItemOrderForm(CssClassMixin, forms.Form):
