@@ -1,14 +1,4 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.assignment.forms
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    Forms for the assignment app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 
 from django import forms
 from django.utils.translation import ugettext_lazy
@@ -16,7 +6,7 @@ from django.utils.translation import ugettext_lazy
 from openslides.utils.forms import CssClassMixin
 from openslides.utils.person import PersonFormField
 
-from openslides.assignment.models import Assignment
+from .models import Assignment
 
 
 class AssignmentForm(forms.ModelForm, CssClassMixin):
