@@ -1,22 +1,13 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.config.views
-    ~~~~~~~~~~~~~~~~~~~~~~~
-
-    Views for the config app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 
 from django import forms
-from django.core.urlresolvers import reverse
 from django.contrib import messages
-from django.utils.translation import ugettext as _, ugettext_lazy
+from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext as _
 
-from openslides.utils.views import FormView
 from openslides.utils.template import Tab
+from openslides.utils.views import FormView
+
 from .api import config
 from .signals import config_signal
 
