@@ -1,39 +1,21 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.motion.models
-    ~~~~~~~~~~~~~~~~~~~~~~~~
-
-    Models for the motion app.
-
-    To use a motion object, you only have to import the Motion class. Any
-    functionality can be reached from a motion object.
-
-    :copyright: (c) 2011–2013 by the OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
-
-from datetime import datetime
 
 from django.core.urlresolvers import reverse
-from django.db import models, IntegrityError
+from django.db import models
 from django.db.models import Max
-from django.dispatch import receiver
 from django.utils import formats
-from django.utils.translation import pgettext
-from django.utils.translation import ugettext as _, ugettext_lazy, ugettext_noop
+from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy, ugettext_noop
 
+from openslides.config.api import config
+from openslides.mediafile.models import Mediafile
+from openslides.poll.models import (BaseOption, BasePoll, BaseVote,
+                                    CountInvalid, CountVotesCast)
+from openslides.projector.models import RelatedModelMixin, SlideMixin
 from openslides.utils.jsonfield import JSONField
 from openslides.utils.person import PersonField
-from openslides.config.api import config
-from openslides.poll.models import (
-    BaseOption, BasePoll, CountVotesCast, CountInvalid, BaseVote)
-from openslides.participant.models import User
-from openslides.projector.api import register_slidemodel
-from openslides.projector.models import SlideMixin
-from openslides.agenda.models import Item
 
-from .exceptions import MotionError, WorkflowError
+from .exceptions import WorkflowError
 
 
 class Motion(SlideMixin, models.Model):
@@ -43,9 +25,9 @@ class Motion(SlideMixin, models.Model):
     This class is the main entry point to all other classes related to a motion.
     """
 
-    prefix = ugettext_noop('motion')
+    slide_callback_name = 'motion'
     """
-    Prefix for the slide system.
+    Name of the callback for the slide-system.
     """
 
     active_version = models.ForeignKey('MotionVersion', null=True,
@@ -84,8 +66,13 @@ class Motion(SlideMixin, models.Model):
     ForeignKey to one category of motions.
     """
 
+    attachments = models.ManyToManyField(Mediafile)
+    """
+    Many to many relation to mediafile objects.
+    """
+
     # TODO: proposal
-    #master = models.ForeignKey('self', null=True, blank=True)
+    # master = models.ForeignKey('self', null=True, blank=True)
 
     class Meta:
         permissions = (
@@ -95,12 +82,13 @@ class Motion(SlideMixin, models.Model):
             ('can_manage_motion', ugettext_noop('Can manage motions')),
         )
         ordering = ('identifier', )
+        verbose_name = ugettext_noop('Motion')
 
     def __unicode__(self):
         """
         Return a human readable name of this motion.
         """
-        return self.active_version.title
+        return self.get_active_version().title
 
     # TODO: Use transaction
     def save(self, use_version=None, *args, **kwargs):
@@ -189,9 +177,10 @@ class Motion(SlideMixin, models.Model):
         if link == 'view' or link == 'detail':
             return reverse('motion_detail', args=[str(self.id)])
         if link == 'update' or link == 'edit':
-            return reverse('motion_edit', args=[str(self.id)])
+            return reverse('motion_update', args=[str(self.id)])
         if link == 'delete':
             return reverse('motion_delete', args=[str(self.id)])
+        return super(Motion, self).get_absolute_url(link)
 
     def version_data_changed(self, version):
         """
@@ -251,7 +240,7 @@ class Motion(SlideMixin, models.Model):
 
     def set_title(self, title):
         """
-        Set the titel of the motion.
+        Set the title of the motion.
 
         The title will be saved in the version object, when motion.save() is
         called.
@@ -463,19 +452,9 @@ class Motion(SlideMixin, models.Model):
                          Workflow.objects.get(pk=config['motion_workflow']).state_set.all()[0])
         self.set_state(new_state)
 
-    def slide(self):
-        """
-        Return the slide dict.
-        """
-        data = super(Motion, self).slide()
-        data['motion'] = self
-        data['title'] = self.title
-        data['template'] = 'projector/Motion.html'
-        return data
-
     def get_agenda_title(self):
         """
-        Return a title for the Agenda.
+        Return a title for the agenda.
         """
         return self.title
 
@@ -563,8 +542,8 @@ class MotionVersion(models.Model):
     creation_time = models.DateTimeField(auto_now=True)
     """Time when the version was saved."""
 
-    #identifier = models.CharField(max_length=255, verbose_name=ugettext_lazy("Version identifier"))
-    #note = models.TextField(null=True, blank=True)
+    # identifier = models.CharField(max_length=255, verbose_name=ugettext_lazy("Version identifier"))
+    # note = models.TextField(null=True, blank=True)
 
     class Meta:
         unique_together = ("motion", "version_number")
@@ -593,7 +572,7 @@ class MotionVersion(models.Model):
         return self.active_version.exists()
 
 
-class MotionSubmitter(models.Model):
+class MotionSubmitter(RelatedModelMixin, models.Model):
     """Save the submitter of a Motion."""
 
     motion = models.ForeignKey('Motion', related_name="submitter")
@@ -606,6 +585,9 @@ class MotionSubmitter(models.Model):
         """Return the name of the submitter as string."""
         return unicode(self.person)
 
+    def get_related_model(self):
+        return self.motion
+
 
 class MotionSupporter(models.Model):
     """Save the submitter of a Motion."""
@@ -643,11 +625,11 @@ class Category(models.Model):
     class Meta:
         ordering = ['prefix']
 
-## class Comment(models.Model):
-    ## motion_version = models.ForeignKey(MotionVersion)
-    ## text = models.TextField()
-    ## author = PersonField()
-    ## creation_time = models.DateTimeField(auto_now=True)
+# class Comment(models.Model):
+    # motion_version = models.ForeignKey(MotionVersion)
+    # text = models.TextField()
+    # author = PersonField()
+    # creation_time = models.DateTimeField(auto_now=True)
 
 
 class MotionLog(models.Model):
@@ -704,7 +686,7 @@ class MotionOption(BaseOption):
     """The VoteClass, to witch this Class links."""
 
 
-class MotionPoll(CountInvalid, CountVotesCast, BasePoll):
+class MotionPoll(RelatedModelMixin, CountInvalid, CountVotesCast, BasePoll):
     """The Class to saves the poll results for a motion poll."""
 
     motion = models.ForeignKey(Motion, related_name='polls')
@@ -730,22 +712,23 @@ class MotionPoll(CountInvalid, CountVotesCast, BasePoll):
         """Return a string, representing the poll."""
         return _('Vote %d') % self.poll_number
 
-    def get_absolute_url(self, link='edit'):
-        """Return an URL for the poll.
-
-        The keyargument 'link' can be 'edit' or 'delete'.
+    def get_absolute_url(self, link='update'):
         """
-        if link == 'edit':
-            return reverse('motion_poll_edit', args=[str(self.motion.pk),
-                                                     str(self.poll_number)])
+        Return an URL for the poll.
+
+        The keyargument 'link' can be 'update' or 'delete'.
+        """
+        if link == 'update':
+            return reverse('motion_poll_update', args=[str(self.motion.pk),
+                                                       str(self.poll_number)])
         if link == 'delete':
             return reverse('motion_poll_delete', args=[str(self.motion.pk),
                                                        str(self.poll_number)])
 
     def set_options(self):
         """Create the option class for this poll."""
-        #TODO: maybe it is possible with .create() to call this without poll=self
-        #      or call this in save()
+        # TODO: maybe it is possible with .create() to call this without poll=self
+        #       or call this in save()
         self.get_option_class()(poll=self).save()
 
     def append_pollform_fields(self, fields):
@@ -753,9 +736,13 @@ class MotionPoll(CountInvalid, CountVotesCast, BasePoll):
         CountInvalid.append_pollform_fields(self, fields)
         CountVotesCast.append_pollform_fields(self, fields)
 
+    def get_related_model(self):
+        return self.motion
+
 
 class State(models.Model):
-    """Defines a state for a motion.
+    """
+    Defines a state for a motion.
 
     Every state belongs to a workflow. All states of a workflow are linked together
     via 'next_states'. One of these states is the first state, but this
