@@ -1,25 +1,16 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.participant.forms
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    Forms for the participant app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 
 from django import forms
-from django.contrib import messages
-from django.contrib.auth.models import Permission
-from django.utils.translation import ugettext as _, ugettext_lazy
 from django.conf import settings
+from django.contrib.auth.models import Permission
+from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy
 
-from openslides.utils.forms import CssClassMixin, LocalizedModelMultipleChoiceField
-from openslides.participant.models import User, Group, get_protected_perm
-from openslides.participant.api import get_registered_group
 from openslides.config.api import config
+from openslides.utils.forms import (CssClassMixin,
+                                    LocalizedModelMultipleChoiceField)
+
+from .models import get_protected_perm, Group, User
 
 
 class UserCreateForm(CssClassMixin, forms.ModelForm):
@@ -51,7 +42,7 @@ class UserUpdateForm(UserCreateForm):
     user edits himself and removes the last group containing the permission
     to manage participants.
     """
-    user_name = forms.CharField()
+    user_name = forms.CharField(label=ugettext_lazy('Username'))
     """
     Field to save the username.
 
@@ -136,7 +127,7 @@ class GroupForm(forms.ModelForm, CssClassMixin):
         # TODO: Check this in clean_users or clean_permissions
         if (self.request and
                 not self.request.user.is_superuser and
-                not self.request.user in self.cleaned_data['users'] and
+                self.request.user not in self.cleaned_data['users'] and
                 not Group.objects.exclude(pk=self.instance.pk).filter(
                     permissions__in=[get_protected_perm()],
                     user__pk=self.request.user.pk).exists()):
@@ -148,13 +139,13 @@ class GroupForm(forms.ModelForm, CssClassMixin):
                 not Group.objects.exclude(pk=self.instance.pk).filter(
                     permissions__in=[get_protected_perm()],
                     user__pk=self.request.user.pk).exists()):
-            error_msg = _('You can not remove the permission to manage participants from the last group your are in.')
+            error_msg = _('You can not remove the permission to manage participants from the last group you are in.')
             raise forms.ValidationError(error_msg)
         return super(GroupForm, self).clean(*args, **kwargs)
 
 
 class UsersettingsForm(CssClassMixin, forms.ModelForm):
-    user_name = forms.CharField()
+    user_name = forms.CharField(label=ugettext_lazy('Username'))
     """
     Field to save the username.
 
@@ -162,9 +153,11 @@ class UsersettingsForm(CssClassMixin, forms.ModelForm):
     allow whitespaces and umlauts.
     """
 
-    language = forms.ChoiceField(choices=settings.LANGUAGES)
+    language = forms.ChoiceField(
+        choices=settings.LANGUAGES, label=ugettext_lazy('Language'))
 
     def __init__(self, *args, **kwargs):
+        kwargs['initial'] = kwargs.get('initial', {})
         kwargs['initial']['user_name'] = kwargs['instance'].username
         return super(UsersettingsForm, self).__init__(*args, **kwargs)
 
