@@ -1,32 +1,25 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.participant.models
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    Models for the participant app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
-
-from django.contrib.auth.models import User as DjangoUser, Group as DjangoGroup, Permission
+from django.contrib.auth.models import Group as DjangoGroup
+from django.contrib.auth.models import User as DjangoUser
+from django.contrib.auth.models import Permission
 from django.contrib.contenttypes.models import ContentType
+from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import signals
 from django.dispatch import receiver
 from django.utils.translation import ugettext_lazy, ugettext_noop
 
-from openslides.utils.person import PersonMixin, Person
-from openslides.utils.person.signals import receive_persons
 from openslides.config.api import config
-from openslides.projector.api import register_slidemodel
-from openslides.projector.projector import SlideMixin
+from openslides.projector.models import SlideMixin
+from openslides.utils.person import Person, PersonMixin
+from openslides.utils.person.signals import receive_persons
 
 
-class User(PersonMixin, Person, SlideMixin, DjangoUser):
-    prefix = 'user'  # This is for the slides
+class User(SlideMixin, PersonMixin, Person, DjangoUser):
+    slide_callback_name = 'user'
     person_prefix = 'user'
+
     GENDER_CHOICES = (
         ('male', ugettext_lazy('Male')),
         ('female', ugettext_lazy('Female')),
@@ -55,6 +48,35 @@ class User(PersonMixin, Person, SlideMixin, DjangoUser):
         max_length=100, blank=True, default='',
         verbose_name=ugettext_lazy("Default password"))
 
+    class Meta:
+        permissions = (
+            ('can_see_participant', ugettext_noop('Can see participants')),
+            ('can_manage_participant', ugettext_noop('Can manage participants')),
+        )
+        ordering = ('last_name',)
+
+    def __unicode__(self):
+        if self.name_suffix:
+            return u"%s (%s)" % (self.clean_name, self.name_suffix)
+        return u"%s" % self.clean_name
+
+    def get_absolute_url(self, link='detail'):
+        """
+        Return the URL to the user.
+        """
+        if link == 'detail' or link == 'view':
+            return reverse('user_view', args=[str(self.id)])
+        if link == 'edit' or link == 'update':
+            return reverse('user_edit', args=[str(self.id)])
+        if link == 'delete':
+            return reverse('user_delete', args=[str(self.id)])
+        return super(User, self).get_absolute_url(link)
+
+    def get_slide_context(self, **context):
+        # Does not call super. In this case the context would override the name
+        # 'user'.
+        return {'shown_user': self}
+
     @property
     def clean_name(self):
         if self.title:
@@ -86,50 +108,9 @@ class User(PersonMixin, Person, SlideMixin, DjangoUser):
             return self.first_name.lower()
         return self.last_name.lower()
 
-    @models.permalink
-    def get_absolute_url(self, link='detail'):
-        """
-        Return the URL to this user.
 
-        link can be:
-        * detail
-        * edit
-        * delete
-        """
-        if link == 'detail' or link == 'view':
-            return ('user_view', [str(self.id)])
-        if link == 'edit':
-            return ('user_edit', [str(self.id)])
-        if link == 'delete':
-            return ('user_delete', [str(self.id)])
-
-    def __unicode__(self):
-        if self.name_suffix:
-            return u"%s (%s)" % (self.clean_name, self.name_suffix)
-        return u"%s" % self.clean_name
-
-    class Meta:
-        # Rename permissions
-        permissions = (
-            ('can_see_participant', ugettext_noop('Can see participants')),  # TODO: Add plural s to the codestring
-            ('can_manage_participant', ugettext_noop('Can manage participants')),  # TODO: Add plural s to the codestring
-        )
-        ordering = ('last_name',)
-
-    def slide(self):
-        """
-        Returns a map with the data for the slides.
-        """
-        return {
-            'shown_user': self,
-            'title': self.clean_name,
-            'template': 'projector/UserSlide.html'}
-
-register_slidemodel(User)
-
-
-class Group(PersonMixin, Person, SlideMixin, DjangoGroup):
-    prefix = 'group'  # This is for the slides
+class Group(SlideMixin, PersonMixin, Person, DjangoGroup):
+    slide_callback_name = 'group'
     person_prefix = 'group'
 
     django_group = models.OneToOneField(DjangoGroup, editable=False, parent_link=True)
@@ -138,39 +119,23 @@ class Group(PersonMixin, Person, SlideMixin, DjangoGroup):
         help_text=ugettext_lazy('For example as submitter of a motion.'))
     description = models.TextField(blank=True, verbose_name=ugettext_lazy("Description"))
 
-    @models.permalink
-    def get_absolute_url(self, link='detail'):
-        """
-        Return the URL to this user group.
-
-        link can be:
-        * view
-        * edit
-        * delete
-        """
-        if link == 'detail' or link == 'view':
-            return ('user_group_view', [str(self.id)])
-        if link == 'edit':
-            return ('user_group_edit', [str(self.id)])
-        if link == 'delete':
-            return ('user_group_delete', [str(self.id)])
+    class Meta:
+        ordering = ('name',)
 
     def __unicode__(self):
         return unicode(self.name)
 
-    class Meta:
-        ordering = ('name',)
-
-    def slide(self):
+    def get_absolute_url(self, link='detail'):
         """
-        Returns a map with the data for the slides.
+        Return the URL to the user group.
         """
-        return {
-            'group': self,
-            'title': self.name,
-            'template': 'projector/GroupSlide.html'}
-
-register_slidemodel(Group)
+        if link == 'detail' or link == 'view':
+            return reverse('user_group_view', args=[str(self.pk)])
+        if link == 'update' or link == 'edit':
+            return reverse('user_group_edit', args=[str(self.pk)])
+        if link == 'delete':
+            return reverse('user_group_delete', args=[str(self.pk)])
+        return super(Group, self).get_absolute_url(link)
 
 
 class UsersAndGroupsToPersons(object):
