@@ -1,30 +1,4 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.participant.views
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    Views for the participant app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
-
-try:
-    import qrcode
-except ImportError:
-    draw_qrcode = False
-else:
-    draw_qrcode = True
-
-from cStringIO import StringIO
-from urllib import urlencode
-from urlparse import parse_qs
-
-from reportlab.lib import colors
-from reportlab.lib.units import cm
-from reportlab.platypus import (
-    SimpleDocTemplate, Paragraph, LongTable, Spacer, Table, TableStyle, Image)
 
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
@@ -32,22 +6,24 @@ from django.contrib.auth.forms import PasswordChangeForm
 from django.contrib.auth.views import login as django_login
 from django.core.urlresolvers import reverse
 from django.shortcuts import redirect
-from django.utils.translation import ugettext as _, ugettext_lazy, activate
+from django.utils.translation import ugettext as _
+from django.utils.translation import activate, ugettext_lazy
 
-from openslides.utils.pdf import stylesheet
-from openslides.utils.template import Tab
-from openslides.utils.utils import (
-    template, delete_default_permissions, html_strong)
-from openslides.utils.views import (
-    FormView, PDFView, CreateView, UpdateView, DeleteView, PermissionMixin,
-    RedirectView, SingleObjectMixin, ListView, QuestionMixin, DetailView)
 from openslides.config.api import config
 from openslides.projector.projector import Widget
-from openslides.participant.api import gen_username, gen_password, import_users
-from openslides.participant.forms import (
-    UserCreateForm, UserUpdateForm, UsersettingsForm,
-    UserImportForm, GroupForm)
-from openslides.participant.models import User, Group, get_protected_perm
+from openslides.utils.template import Tab
+from openslides.utils.utils import (delete_default_permissions, html_strong,
+                                    template)
+from openslides.utils.views import (CreateView, DeleteView, DetailView,
+                                    FormView, ListView, PDFView,
+                                    PermissionMixin, QuestionView,
+                                    RedirectView, SingleObjectMixin, UpdateView)
+
+from .api import gen_password, gen_username, import_users
+from .forms import (GroupForm, UserCreateForm, UserImportForm, UsersettingsForm,
+                    UserUpdateForm)
+from .models import get_protected_perm, Group, User
+from .pdf import participants_to_pdf, participants_passwords_to_pdf
 
 
 class UserOverview(ListView):
@@ -96,6 +72,7 @@ class UserCreateView(CreateView):
     context_object_name = 'edit_user'
     form_class = UserCreateForm
     success_url_name = 'user_overview'
+    url_name_args = []
 
     def manipulate_object(self, form):
         self.object.username = gen_username(
@@ -126,6 +103,7 @@ class UserUpdateView(UpdateView):
     context_object_name = 'edit_user'
     form_class = UserUpdateForm
     success_url_name = 'user_overview'
+    url_name_args = []
 
     def get_form_kwargs(self, *args, **kwargs):
         form_kwargs = super(UserUpdateView, self).get_form_kwargs(*args, **kwargs)
@@ -154,6 +132,7 @@ class UserDeleteView(DeleteView):
     permission_required = 'participant.can_manage_participant'
     model = User
     success_url_name = 'user_overview'
+    url_name_args = []
 
     def pre_redirect(self, request, *args, **kwargs):
         if self.object == self.request.user:
@@ -168,13 +147,14 @@ class UserDeleteView(DeleteView):
             super(UserDeleteView, self).pre_post_redirect(request, *args, **kwargs)
 
 
-class SetUserStatusView(RedirectView, SingleObjectMixin):
+class SetUserStatusView(SingleObjectMixin, RedirectView):
     """
     Activate or deactivate an user.
     """
     permission_required = 'participant.can_manage_participant'
     allow_ajax = True
     url_name = 'user_overview'
+    url_name_args = []
     model = User
 
     def pre_redirect(self, request, *args, **kwargs):
@@ -185,8 +165,8 @@ class SetUserStatusView(RedirectView, SingleObjectMixin):
         elif action == 'deactivate':
             if self.object.user == self.request.user:
                 messages.error(request, _("You can not deactivate yourself."))
-                return
-            self.object.is_active = False
+            else:
+                self.object.is_active = False
         elif action == 'toggle':
             self.object.is_active = not self.object.is_active
         self.object.save()
@@ -206,111 +186,29 @@ class ParticipantsListPDF(PDFView):
     filename = ugettext_lazy("Participant-list")
     document_title = ugettext_lazy('List of Participants')
 
-    def append_to_pdf(self, story):
-        data = [['#', _('Title'), _('Last Name'), _('First Name'),
-                 _('Structure level'), _('Group'), _('Committee')]]
-        if config['participant_sort_users_by_first_name']:
-            sort = 'first_name'
-        else:
-            sort = 'last_name'
-        counter = 0
-        for user in User.objects.all().order_by(sort):
-            counter += 1
-            groups = ''
-            for group in user.groups.all():
-                if group.pk != 2:
-                    groups += "%s<br/>" % unicode(_(group.name))
-            data.append([
-                counter,
-                Paragraph(user.title, stylesheet['Tablecell']),
-                Paragraph(user.last_name, stylesheet['Tablecell']),
-                Paragraph(user.first_name, stylesheet['Tablecell']),
-                Paragraph(user.structure_level, stylesheet['Tablecell']),
-                Paragraph(groups, stylesheet['Tablecell']),
-                Paragraph(user.committee, stylesheet['Tablecell'])])
-        t = LongTable(data, style=[
-            ('VALIGN', (0, 0), (-1, -1), 'TOP'),
-            ('LINEABOVE', (0, 0), (-1, 0), 2, colors.black),
-            ('LINEABOVE', (0, 1), (-1, 1), 1, colors.black),
-            ('LINEBELOW', (0, -1), (-1, -1), 2, colors.black),
-            ('ROWBACKGROUNDS', (0, 1), (-1, -1),
-                (colors.white, (.9, .9, .9)))])
-        t._argW[0] = 0.75 * cm
-        story.append(t)
+    def append_to_pdf(self, pdf):
+        """
+        Append PDF objects.
+        """
+        participants_to_pdf(pdf)
 
 
 class ParticipantsPasswordsPDF(PDFView):
     """
-    Generate the Welcomepaper for the users.
+    Generate the access data welcome paper for all participants as PDF.
     """
     permission_required = 'participant.can_manage_participant'
-    filename = ugettext_lazy("Participant-passwords")
+    filename = ugettext_lazy("Participant-access-data")
     top_space = 0
 
-    def get_template(self, buffer):
-        return SimpleDocTemplate(
-            buffer, topMargin=-6, bottomMargin=-6,
-            leftMargin=0, rightMargin=0, showBoundary=False)
-
     def build_document(self, pdf_document, story):
         pdf_document.build(story)
 
-    def append_to_pdf(self, story):
-        data = []
-        participant_pdf_system_url = config["participant_pdf_system_url"]
-        participant_pdf_welcometext = config["participant_pdf_welcometext"]
-        if config['participant_sort_users_by_first_name']:
-            sort = 'first_name'
-        else:
-            sort = 'last_name'
-        # create qrcode image object from system url
-        if draw_qrcode:
-            qrcode_img = qrcode.make(participant_pdf_system_url)
-            img_stream = StringIO()
-            qrcode_img.save(img_stream, 'PNG')
-            img_stream.seek(0)
-            size = 2 * cm
-            I = Image(img_stream, width=size, height=size)
-        for user in User.objects.all().order_by(sort):
-            cell = []
-            cell.append(Spacer(0, 0.8 * cm))
-            cell.append(Paragraph(_("Account for OpenSlides"),
-                        stylesheet['Password_title']))
-            cell.append(Paragraph(_("for %s") % (user),
-                        stylesheet['Password_subtitle']))
-            cell.append(Spacer(0, 0.5 * cm))
-            cell.append(Paragraph(_("User: %s") % (user.username),
-                        stylesheet['Monotype']))
-            cell.append(
-                Paragraph(
-                    _("Password: %s")
-                    % (user.default_password), stylesheet['Monotype']))
-            cell.append(
-                Paragraph(participant_pdf_system_url, stylesheet['Monotype']))
-            if draw_qrcode:
-                cell.append(I)
-            cell2 = []
-            cell2.append(Spacer(0, 0.8 * cm))
-            if participant_pdf_welcometext is not None:
-                cell2.append(Paragraph(
-                    participant_pdf_welcometext.replace('\r\n', '<br/>'),
-                    stylesheet['Ballot_subtitle']))
-
-            data.append([cell, cell2])
-
-        # add empty table line if no participants available
-        if not data:
-            data.append(['', ''])
-        # build table
-        t = Table(data, 10.5 * cm, 7.42 * cm)
-        t.setStyle(TableStyle([
-            ('LEFTPADDING', (0, 0), (0, -1), 30),
-            ('LINEBELOW', (0, 0), (-1, 0), 0.25, colors.grey),
-            ('LINEBELOW', (0, 1), (-1, 1), 0.25, colors.grey),
-            ('LINEBELOW', (0, 1), (-1, -1), 0.25, colors.grey),
-            ('VALIGN', (0, 0), (-1, -1), 'TOP'),
-        ]))
-        story.append(t)
+    def append_to_pdf(self, pdf):
+        """
+        Append PDF objects.
+        """
+        participants_passwords_to_pdf(pdf)
 
 
 class UserImportView(FormView):
@@ -334,14 +232,14 @@ class UserImportView(FormView):
         return super(UserImportView, self).form_valid(form)
 
 
-class ResetPasswordView(SingleObjectMixin, QuestionMixin, RedirectView):
+class ResetPasswordView(SingleObjectMixin, QuestionView):
     """
     Set the Passwort for a user to his default password.
     """
     permission_required = 'participant.can_manage_participant'
     model = User
     allow_ajax = True
-    question = ugettext_lazy('Do you really want to reset the password?')
+    question_message = ugettext_lazy('Do you really want to reset the password?')
 
     def get(self, request, *args, **kwargs):
         self.object = self.get_object()
@@ -350,10 +248,10 @@ class ResetPasswordView(SingleObjectMixin, QuestionMixin, RedirectView):
     def get_redirect_url(self, **kwargs):
         return reverse('user_edit', args=[self.object.id])
 
-    def case_yes(self):
+    def on_clicked_yes(self):
         self.object.reset_password()
 
-    def get_success_message(self):
+    def get_final_message(self):
         return _('The Password for %s was successfully reset.') % html_strong(self.object)
 
 
@@ -397,6 +295,7 @@ class GroupCreateView(CreateView):
     model = Group
     form_class = GroupForm
     success_url_name = 'user_group_overview'
+    url_name_args = []
 
     def get(self, request, *args, **kwargs):
         delete_default_permissions()
@@ -413,6 +312,7 @@ class GroupUpdateView(UpdateView):
     context_object_name = 'group'
     form_class = GroupForm
     success_url_name = 'user_group_overview'
+    url_name_args = []
 
     def get(self, request, *args, **kwargs):
         delete_default_permissions()
@@ -431,6 +331,7 @@ class GroupDeleteView(DeleteView):
     permission_required = 'participant.can_manage_participant'
     model = Group
     success_url_name = 'user_group_overview'
+    url_name_args = []
 
     def pre_redirect(self, request, *args, **kwargs):
         if not self.is_protected_from_deleting():
@@ -445,7 +346,7 @@ class GroupDeleteView(DeleteView):
         Checks whether the group is protected.
         """
         if self.object.pk in [1, 2]:
-            messages.error(request, _('You can not delete this group.'))
+            messages.error(self.request, _('You can not delete this group.'))
             return True
         if (not self.request.user.is_superuser and
             get_protected_perm() in self.object.permissions.all() and
@@ -465,14 +366,17 @@ def login(request):
     try:
         admin = User.objects.get(pk=1)
         if admin.check_password(admin.default_password):
+            user_data = {
+                'user': html_strong(admin.username),
+                'password': html_strong(admin.default_password)}
+
             extra_content['first_time_message'] = _(
                 "Installation was successfully! Use %(user)s "
                 "(password: %(password)s) for first login.<br>"
                 "<strong>Important:</strong> Please change the password after "
                 "first login! Otherwise this message still appears for "
-                "everyone  and could be a security risk.") % {
-                    'user': html_strong(admin.username),
-                    'password': html_strong(admin.default_password)}
+                "everyone  and could be a security risk.") % user_data
+
             extra_content['next'] = reverse('password_change')
     except User.DoesNotExist:
         pass
@@ -564,7 +468,8 @@ def get_user_widget(request):
         template='participant/user_widget.html',
         context={'users': User.objects.all()},
         permission_required='projector.can_manage_projector',
-        default_column=1)
+        default_column=1,
+        default_weight=60)
 
 
 def get_group_widget(request):
@@ -579,4 +484,5 @@ def get_group_widget(request):
         template='participant/group_widget.html',
         context={'groups': Group.objects.all()},
         permission_required='projector.can_manage_projector',
-        default_column=1)
+        default_column=1,
+        default_weight=70)
