@@ -1,46 +1,32 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.projector.signals
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    Signals for the projector app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 from time import time
 
-from django.dispatch import Signal, receiver
-from django import forms
-from django.template.loader import render_to_string
+from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.core.context_processors import csrf
+from django.dispatch import receiver, Signal
+from django.template.loader import render_to_string
+from django.utils.datastructures import SortedDict
 
-from openslides.config.api import config
+from openslides.config.api import config, ConfigPage, ConfigVariable
 from openslides.config.signals import config_signal
-from openslides.config.api import ConfigVariable, ConfigPage
 
 from .projector import Overlay
-from .api import clear_projector_cache
-
 
 projector_overlays = Signal(providing_args=['request'])
 
 
 @receiver(config_signal, dispatch_uid='setup_projector_config_variables')
-def setup_projector_config_variables(sender, **kwargs):
+def config_variables(sender, **kwargs):
     """
     Projector config variables for OpenSlides. They are not shown on a
     config page.
     """
 
-    presentation = ConfigVariable(
-        name='presentation',
-        default_value='')
-
-    presentation_argument = ConfigVariable(
-        name='presentation_argument',
-        default_value=None)
+    # The active slide. The config-value is a dictonary with at least the entry
+    # 'callback'.
+    projector = ConfigVariable(
+        name='projector_active_slide',
+        default_value={'callback': None})
 
     projector_message = ConfigVariable(
         name='projector_message',
@@ -62,23 +48,33 @@ def setup_projector_config_variables(sender, **kwargs):
         name='countdown_state',
         default_value='inactive')
 
-    bigger = ConfigVariable(
-        name='bigger',
-        default_value=100)
-
-    up = ConfigVariable(
-        name='up',
+    projector_scale = ConfigVariable(
+        name='projector_scale',
         default_value=0)
 
+    projector_scroll = ConfigVariable(
+        name='projector_scroll',
+        default_value=0)
+
+    projector_js_cache = ConfigVariable(
+        name='projector_js_cache',
+        default_value={})
+
     projector_active_overlays = ConfigVariable(
         name='projector_active_overlays',
         default_value=[])
 
+    projector_pdf_fullscreen = ConfigVariable(
+        name='pdf_fullscreen',
+        default_value=False)
+
     return ConfigPage(
         title='No title here', url='bar', required_permission=None, variables=(
-            presentation, presentation_argument, projector_message,
+            projector, projector_message,
             countdown_time, countdown_start_stamp, countdown_pause_stamp,
-            countdown_state, bigger, up, projector_active_overlays))
+            countdown_state, projector_scale, projector_scroll,
+            projector_active_overlays, projector_js_cache,
+            projector_pdf_fullscreen))
 
 
 @receiver(projector_overlays, dispatch_uid="projector_countdown")
@@ -97,34 +93,33 @@ def countdown(sender, **kwargs):
             'countdown_time': config['countdown_time'],
             'countdown_state': config['countdown_state']}
         context.update(csrf(request))
-        return render_to_string('projector/overlay_countdown_widget.html', context)
+        return render_to_string('projector/overlay_countdown_widget.html',
+                                context)
+
+    def get_projector_js():
+        """
+        Returns JavaScript for the projector
+        """
+        value = SortedDict()
+        value['load_file'] = static('javascript/countdown.js')
+        value['projector_countdown_start'] = int(config['countdown_start_stamp'])
+        value['projector_countdown_duration'] = int(config['countdown_time'])
+        value['projector_countdown_pause'] = int(config['countdown_pause_stamp'])
+        value['projector_countdown_state'] = config['countdown_state']
+        value['call'] = 'update_countdown();'
+        return value
 
     def get_projector_html():
         """
         Returns an html-code to show on the projector.
         """
-        start = config['countdown_start_stamp']
-        duration = config['countdown_time']
-        pause = config['countdown_pause_stamp']
-        if config['countdown_state'] == 'active':
-            seconds = max(0, int(start + duration - time()))
-        elif config['countdown_state'] == 'paused':
-            seconds = max(0, int(start + duration - pause))
-        elif config['countdown_state'] == 'inactive':
-            seconds = max(0, int(duration))
-        else:
-            seconds = 0
-        if seconds == 0:
-            config['countdown_state'] = 'expired'
-        clear_projector_cache()
-        return render_to_string('projector/overlay_countdown_projector.html',
-                                {'seconds': '%02d:%02d' % (seconds / 60, seconds % 60)})
+        return render_to_string('projector/overlay_countdown_projector.html')
 
-    return Overlay(name, get_widget_html, get_projector_html)
+    return Overlay(name, get_widget_html, get_projector_html, get_projector_js)
 
 
-@receiver(projector_overlays, dispatch_uid="projector_message")
-def projector_message(sender, **kwargs):
+@receiver(projector_overlays, dispatch_uid="projector_overlay_message")
+def projector_overlay_message(sender, **kwargs):
     """
     Receiver to show the overlay_message on the projector or the form in the
     overlay-widget on the dashboard.
@@ -148,3 +143,28 @@ def projector_message(sender, **kwargs):
         return None
 
     return Overlay(name, get_widget_html, get_projector_html)
+
+
+@receiver(projector_overlays, dispatch_uid="projector_clock")
+def projector_clock(sender, **kwargs):
+    """
+    Receiver to show the clock on the projector.
+    """
+    name = 'projector_clock'
+
+    def get_projector_html():
+        """
+        Returns the html-code for the clock.
+        """
+        return render_to_string('projector/overlay_clock_projector.html')
+
+    def get_projector_js():
+        """
+        Returns JavaScript for the projector
+        """
+        javascript = 'projector.set_server_time(%d);update_clock();' % int(time())
+        return {'load_file': static('javascript/clock.js'),
+                'call': javascript}
+
+    return Overlay(name, None, get_projector_html, get_projector_js,
+                   allways_active=True)
